@@ -5,6 +5,8 @@ OC.L10N.register(
     "All contacts" : "Alla kontakter",
     "Details" : "Detaljer",
     "A contacts app for Nextcloud" : "En kontakt-app för Nextcloud",
+    "Copy to full name" : "Kopiera till fullständigt namn",
+    "Omit year" : "Utelämna år",
     "Add new property" : "Lägg till nytt fält",
     "Choose property type" : "Välj typ",
     "Add a new picture" : "Lägg till en ny bild",
@@ -79,9 +81,9 @@ OC.L10N.register(
     "Additional names" : "Mellannamn",
     "Prefix" : "Prefix",
     "Suffix" : "Suffix",
-    "Copy to full name" : "Kopiera till fullständigt namn",
     "Notes" : "Anteckningar",
     "Website" : "Webbplats",
+    "Location" : "Plats",
     "Federated Cloud ID" : "Federerat Moln-ID",
     "Home" : "Hem",
     "Work" : "Arbete",
